@@ -2,15 +2,13 @@ import os
 
 
 def get_config_dir() -> str:
-    parent = os.environ.get('XDG_CONFIG_HOME') or os.path.join(
+    root = os.environ.get('XDG_CONFIG_HOME') or os.path.join(
         os.path.expanduser('~'), '.config')
-    root = os.path.join(parent, "gita")
-    return root
+    return os.path.join(root, "gita")
 
 
 def get_config_fname(fname: str) -> str:
     """
     Return the file name that stores the repo locations.
     """
-    root = get_config_dir()
-    return os.path.join(root, fname)
+    return os.path.join(get_config_dir(), fname)
