@@ -8,9 +8,9 @@ from gita import info
 def test_run_quiet_diff(mock_run):
     mock_return = MagicMock()
     mock_run.return_value = mock_return
-    got = info.run_quiet_diff(['my', 'args'])
+    got = info.run_quiet_diff(['--flags'], ['my', 'args'])
     mock_run.assert_called_once_with(
-        ['git', 'diff', '--quiet', 'my', 'args'],
+        ['git', '--flags', 'diff', '--quiet', 'my', 'args'],
         stderr=subprocess.DEVNULL,
     )
     assert got == mock_return.returncode
